@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Inspect Musical Modal Functions
 
-our $VERSION = '0.0202';
+our $VERSION = '0.0300';
 
 use Moo;
 use strictures 2;
@@ -108,7 +108,7 @@ sub _build__database {
         for my $mode (sort keys %{ $self->_modes }) {
             my @pitches;
             my @notes = get_scale_notes($base, $mode);
-            warn "$base $mode @notes\n" if $self->verbose;
+            warn "Basics: $base $mode [@notes]\n" if $self->verbose;
             for my $note (@notes) {
                 my $n = Music::Note->new($note, 'isobase');
                 $n->en_eq('flat') if $note =~ /#/;
@@ -116,15 +116,15 @@ sub _build__database {
             }
             my $i = 0;
             for my $pitch (@pitches) {
-                my $chord = $self->_modes->{$mode}[$i]{chord};
+                my $chord    = $self->_modes->{$mode}[$i]{chord};
                 my $function = $self->_modes->{$mode}[$i]{function};
-                my $roman = $self->_modes->{$mode}[$i]{roman};
+                my $roman    = $self->_modes->{$mode}[$i]{roman};
                 $database .= "chord_key($pitch, $chord, $mode_base, $mode, $function, $roman).\n";
                 $i++;
             }
         }
     }
-    $database .=<<'RULE';
+    $database .= <<'RULES';
 % Can a chord in one key function in a second?
 pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman, Key2Note, Key2, Key2Function, Key2Roman) :-
     % bind the chord to the function of the first key
@@ -133,8 +133,14 @@ pivot_chord_keys(ChordNote, Chord, Key1Note, Key1, Key1Function, Key1Roman, Key2
     chord_key(ChordNote, Chord, Key2Note, Key2, Key2Function, Key2Roman),
     % the functions cannot be the same
     Key1Function \= Key2Function.
-RULE
-    warn "$database\n" if $self->verbose;
+
+% TODO
+roman_key(Mode, ModeRoman, Key, KeyRoman) :-
+    chord_key(_, _, _, Mode, ModeFunction, ModeRoman),
+    chord_key(_, _, _, Key, KeyFunction, KeyRoman),
+    ModeFunction \= KeyFunction.
+RULES
+    warn "Database: $database\n" if $self->verbose;
     return $database;
 }
 
@@ -178,12 +184,24 @@ sub pivot_chord_keys {
     return $self->_querydb($query);
 }
 
+
+sub roman_key {
+    my ($self) = @_;
+    my $query = sprintf 'roman_key(%s, %s, %s, %s).',
+        defined $self->mode       ? $self->mode       : 'Mode',
+        defined $self->mode_roman ? $self->mode_roman : 'ModeRoman',
+        defined $self->key        ? $self->key        : 'Key',
+        defined $self->key_roman  ? $self->key_roman  : 'KeyRoman',
+    ;
+    return $self->_querydb($query);
+}
+
 sub _querydb {
     my ($self, $query) = @_;
+    warn "Query: $query\n" if $self->verbose;
     $self->_prolog->query($query);
     my @return;
     while (my $result = $self->_prolog->results) {
-#warn __PACKAGE__,' L',__LINE__,' R: ',join(',',@$result),"\n";
         push @return, $result;
     }
     return \@return;
@@ -203,7 +221,7 @@ Music::ModalFunction - Inspect Musical Modal Functions
 
 =head1 VERSION
 
-version 0.0202
+version 0.0300
 
 =head1 SYNOPSIS
 
@@ -285,8 +303,8 @@ Arguments:
 
   chord_key(ChordNote, Chord, KeyNote, Key, KeyFunction, KeyRoman)
 
-If defined, the argument in that position will be bound to that value
-(e.g. C<'_'> even). Otherwise an unbound variable is used.
+If defined, argument values will be bound to a variable. Otherwise an
+unbound variable is used.
 
 =head2 pivot_chord_keys
 
@@ -298,8 +316,22 @@ Arguments:
 
   pivot_chord_keys(ChordNote, Chord, ModeNote, Mode, ModeFunction, ModeRoman, KeyNote, Key, KeyFunction, KeyRoman)
 
-If defined, the argument in that position will be bound to that value.
-Otherwise an unbound variable is used.
+If defined, argument values will be bound to a variable. Otherwise an
+unbound variable is used.
+
+=head2 roman_key
+
+  $q = $m->roman_key;
+
+Ask the database a question about what Roman numeral functional chords
+share common keys.
+
+Arguments:
+
+  roman_key(Mode, ModeRoman, Key, KeyRoman)
+
+If defined, argument values will be bound to a variable. Otherwise an
+unbound variable is used.
 
 =head1 SEE ALSO
 
